@@ -1,6 +1,7 @@
-#ifndef PROFILECHANGERWIDGET_H
-#define PROFILECHANGERWIDGET_H
+#ifndef _PROFILECHANGERWIDGET_H_
+#define _PROFILECHANGERWIDGET_H_
 
+#include <QMainWindow>
 #include <QDBusInterface>
 #include <qmaemo5homescreenadaptor.h>
 #include <QErrorMessage>
@@ -10,12 +11,12 @@ namespace Ui {
     class ProfileChangerWidget;
 }
 
-class ProfileChangerWidget : public QWidget
+class ProfileChangerWidget : public QMainWindow
 {
     Q_OBJECT
 
 public:
-    explicit ProfileChangerWidget(QWidget *parent = 0);
+    explicit ProfileChangerWidget (QWidget *parent = 0);
     ~ProfileChangerWidget();
 
 
@@ -36,5 +37,5 @@ private:
     void refreshIcon();
 };
 
-#endif // PROFILECHANGERWIDGET_H
+#endif // _PROFILECHANGERWIDGET_H_
 
